#!/usr/bin/env sh

# Handle the command line arguments
[ -z "$1" ] && { echo "Usage: auction.sh <target.org>"; exit 1; }
i=1
for arg in "$@"; do
    if [ $i -eq $# ]; then
        TARGET=$arg
    else
        if [ "$(expr "$arg" : 'url=.*')" -gt 0 ]; then
            URL=$(echo "$arg" | cut -c5-)
        else
            echo "Error: Unknown argument \"$arg\""
            exit 1
        fi
    fi
    i=$(( i + 1 ))
done

# Make sure the target exists
[ -e "$TARGET" ] || { echo "Error: File \"$TARGET\" not found"; exit 1; }

# Get the title
TITLE=$(grep -i "#+TITLE: " "$TARGET" | sed "s/\#+TITLE: //I")
[ -z "$TITLE" ] && { echo "Error: Document must have a title"; exit 1; }

# Directory and file name handling
OUTPUTDIR=$(pwd)
TARGETPATH=$(readlink -f "$TARGET")
TARGETNAME=$(basename "$TARGETPATH")
SCRIPTPATH=$(dirname "$(readlink -f "$0")")
cd "$SCRIPTPATH"/internal || { echo "Error: Could not access \"internal\" directory"; exit 1; }

if [ "$(expr "$TARGETNAME" : '.*\.org$')" -gt 0 ]; then
    OUTPUTNAME=$(echo "$TARGETNAME" | sed "s/\.org$/.html/I")
else
    OUTPUTNAME=$TARGETNAME.html
fi

# Export the partial HTML
echo "Exporting \"$TARGET\""
PARTIALHTML=$(mktemp)
echo "Building partial HTML in temporary file $PARTIALHTML"
./export.awk \
    -v header=h1 maxHeaderLevel=6 wrapHeadingBodies=true \
    "$TARGETPATH" 3>/dev/null 1>"$PARTIALHTML" || { rm "$PARTIALHTML"; exit 1; }

echo "Filling template"
AWK_FILLER=$(cat <<END
/#\+CONTENT/ { while (("cat $PARTIALHTML" | getline) > 0) { print }; next } \
/#\+TITLE/ { print "$TITLE"; next; } \
/#\+HOSTURL/ { printf("HOSTURL = \"%s\"\n", url); next; } \
/#\+STYLE/ { while (("cat ./style.css" | getline) > 0) { print }; next } \
/#\+SCRIPT/ { while (("cat ./script.js" | getline) > 0) { print }; next } \
// { print; }
END
)
# Build base.html
awk -v url="$URL" "$AWK_FILLER" ./base.html > "$OUTPUTDIR/$OUTPUTNAME"

rm "$PARTIALHTML"
echo "Done."
